@@ -1,18 +1,15 @@
 
 #define PACKAGE_NAME    "Qsynth"
-#define PACKAGE_VERSION "0.2.5"
-
+#define PACKAGE_VERSION "0.3.2"
 
 #define CONFIG_PREFIX   "."
 #define CONFIG_DEBUG    1
 
-#undef  CONFIG_SYSTEM_TRAY
+#define CONFIG_SYSTEM_TRAY
 
+#if !defined(__MINGW32__)
 #undef  CONFIG_FLUID_SERVER
 #undef  CONFIG_FLUID_RESET
 #undef  CONFIG_FLUID_BANK_OFFSET
-
 #undef  CONFIG_ROUND
-
-#undef  HAVE_SIGNAL_H
-
+#endif
